[gimp/multi-stroke: 11/30] app: s/nfoo/n_foo/.



commit 426b845b9cbe7ba661c2b8ccf4e97b3f49fcf2db
Author: Jehan <jehan girinstud io>
Date:   Sun Mar 22 00:48:32 2015 +0100

    app: s/nfoo/n_foo/.

 app/core/gimpsymmetry-mirror.c   |   12 ++++++------
 app/core/gimpsymmetry-tiling.c   |    6 +++---
 app/core/gimpsymmetry.c          |   18 +++++++++---------
 app/core/gimpsymmetry.h          |    8 ++++----
 app/paint/gimpconvolve.c         |    6 +++---
 app/paint/gimpdodgeburn.c        |    6 +++---
 app/paint/gimperaser.c           |    6 +++---
 app/paint/gimpink.c              |   12 ++++++------
 app/paint/gimppaintbrush.c       |    7 ++++---
 app/paint/gimpperspectiveclone.c |    6 +++---
 app/paint/gimpsmudge.c           |   12 ++++++------
 app/paint/gimpsourcecore.c       |    6 +++---
 12 files changed, 53 insertions(+), 52 deletions(-)
---
diff --git a/app/core/gimpsymmetry-mirror.c b/app/core/gimpsymmetry-mirror.c
index 6a192bd..056947b 100644
--- a/app/core/gimpsymmetry-mirror.c
+++ b/app/core/gimpsymmetry-mirror.c
@@ -81,9 +81,9 @@ static void       gimp_mirror_guide_position_cb   (GObject      *object,
                                                    GParamSpec   *pspec,
                                                    GimpMirror   *mirror);
 static GParamSpec ** gimp_mirror_get_settings     (GimpSymmetry *sym,
-                                                   guint        *nsettings);
+                                                   guint        *n_settings);
 static GParamSpec ** gimp_mirror_get_xcf_settings (GimpSymmetry *sym,
-                                                   guint        *nsettings);
+                                                   guint        *n_settings);
 static void  gimp_mirror_set_horizontal_symmetry  (GimpMirror   *mirror,
                                                    gboolean      active);
 static void    gimp_mirror_set_vertical_symmetry  (GimpMirror   *mirror,
@@ -464,11 +464,11 @@ gimp_mirror_guide_position_cb (GObject    *object,
 
 static GParamSpec **
 gimp_mirror_get_settings (GimpSymmetry *sym,
-                          guint        *nsettings)
+                          guint        *n_settings)
 {
   GParamSpec **pspecs;
 
-  *nsettings = 5;
+  *n_settings = 5;
   pspecs = g_new (GParamSpec*, 5);
 
   pspecs[0] = g_object_class_find_property (G_OBJECT_GET_CLASS (sym),
@@ -486,11 +486,11 @@ gimp_mirror_get_settings (GimpSymmetry *sym,
 
 static GParamSpec **
 gimp_mirror_get_xcf_settings (GimpSymmetry *sym,
-                              guint        *nsettings)
+                              guint        *n_settings)
 {
   GParamSpec **pspecs;
 
-  *nsettings = 6;
+  *n_settings = 6;
   pspecs = g_new (GParamSpec*, 6);
 
   pspecs[0] = g_object_class_find_property (G_OBJECT_GET_CLASS (sym),
diff --git a/app/core/gimpsymmetry-tiling.c b/app/core/gimpsymmetry-tiling.c
index a6ef8c9..96fe1c8 100644
--- a/app/core/gimpsymmetry-tiling.c
+++ b/app/core/gimpsymmetry-tiling.c
@@ -72,7 +72,7 @@ static GeglNode * gimp_tiling_get_operation      (GimpSymmetry *tiling,
                                                   gint          paint_width,
                                                   gint          paint_height);
 static GParamSpec ** gimp_tiling_get_settings    (GimpSymmetry *sym,
-                                                  guint        *nsettings);
+                                                  guint        *n_settings);
 static void
                gimp_tiling_image_size_changed_cb (GimpImage    *image ,
                                                   gint          previous_origin_x,
@@ -353,11 +353,11 @@ gimp_tiling_get_operation (GimpSymmetry *sym,
 
 static GParamSpec **
 gimp_tiling_get_settings (GimpSymmetry *sym,
-                          guint        *nsettings)
+                          guint        *n_settings)
 {
   GParamSpec **pspecs;
 
-  *nsettings = 6;
+  *n_settings = 6;
   pspecs = g_new (GParamSpec*, 6);
 
   pspecs[0] = g_object_class_find_property (G_OBJECT_GET_CLASS (sym),
diff --git a/app/core/gimpsymmetry.h b/app/core/gimpsymmetry.h
index d702126..6c9eee5 100644
--- a/app/core/gimpsymmetry.h
+++ b/app/core/gimpsymmetry.h
@@ -63,10 +63,10 @@ struct _GimpSymmetryClass
                                              gint          paint_height);
   GParamSpec **
              (* get_settings)               (GimpSymmetry *sym,
-                                             guint        *nproperties);
+                                             guint        *n_properties);
   GParamSpec **
              (* get_xcf_settings)           (GimpSymmetry *sym,
-                                             guint        *nproperties);
+                                             guint        *n_properties);
 };
 
 
@@ -85,8 +85,8 @@ GeglNode   * gimp_symmetry_get_operation    (GimpSymmetry *sym,
                                              gint          paint_width,
                                              gint          paint_height);
 GParamSpec ** gimp_symmetry_get_settings     (GimpSymmetry *sym,
-                                              guint        *nproperties);
+                                              guint        *n_properties);
 GParamSpec ** gimp_symmetry_get_xcf_settings (GimpSymmetry *sym,
-                                              guint        *nproperties);
+                                              guint        *n_properties);
 
 #endif  /*  __GIMP_SYMMETRY_H__  */
diff --git a/app/paint/gimpconvolve.c b/app/paint/gimpconvolve.c
index b6d7d2e..c4a85a3 100644
--- a/app/paint/gimpconvolve.c
+++ b/app/paint/gimpconvolve.c
@@ -142,14 +142,14 @@ gimp_convolve_motion (GimpPaintCore    *paint_core,
   const GimpCoords    *coords;
   GeglNode            *op;
   gint                 paint_width, paint_height;
-  gint                 nstrokes;
+  gint                 n_strokes;
   gint                 i;
 
-  nstrokes = gimp_symmetry_get_size (sym);
+  n_strokes = gimp_symmetry_get_size (sym);
   fade_point = gimp_paint_options_get_fade (paint_options, image,
                                             paint_core->pixel_dist);
 
-  for (i = 0; i < nstrokes; i++)
+  for (i = 0; i < n_strokes; i++)
     {
       coords = gimp_symmetry_get_coords (sym, i);
 
diff --git a/app/paint/gimpdodgeburn.c b/app/paint/gimpdodgeburn.c
index 092d94d..4ed2605 100644
--- a/app/paint/gimpdodgeburn.c
+++ b/app/paint/gimpdodgeburn.c
@@ -125,11 +125,11 @@ gimp_dodge_burn_motion (GimpPaintCore    *paint_core,
   const GimpCoords     *coords;
   GeglNode             *op;
   gint                  paint_width, paint_height;
-  gint                  nstrokes;
+  gint                  n_strokes;
   gint                  i;
 
-  nstrokes = gimp_symmetry_get_size (sym);
-  for (i = 0; i < nstrokes; i++)
+  n_strokes = gimp_symmetry_get_size (sym);
+  for (i = 0; i < n_strokes; i++)
     {
       coords = gimp_symmetry_get_coords (sym, i);
 
diff --git a/app/paint/gimperaser.c b/app/paint/gimperaser.c
index d26ab09..792d08e 100644
--- a/app/paint/gimperaser.c
+++ b/app/paint/gimperaser.c
@@ -119,7 +119,7 @@ gimp_eraser_motion (GimpPaintCore    *paint_core,
   gdouble               force;
   const GimpCoords     *coords;
   GeglNode             *op;
-  gint                  nstrokes;
+  gint                  n_strokes;
   gint                  paint_width, paint_height;
   gint                  i;
 
@@ -136,9 +136,9 @@ gimp_eraser_motion (GimpPaintCore    *paint_core,
   else
     paint_mode = GIMP_NORMAL_MODE;
 
-  nstrokes = gimp_symmetry_get_size (sym);
+  n_strokes = gimp_symmetry_get_size (sym);
 
-  for (i = 0; i < nstrokes; i++)
+  for (i = 0; i < n_strokes; i++)
     {
       coords = gimp_symmetry_get_coords (sym, i);
 
diff --git a/app/paint/gimpink.c b/app/paint/gimpink.c
index 66e258d..4a18d3e 100644
--- a/app/paint/gimpink.c
+++ b/app/paint/gimpink.c
@@ -304,13 +304,13 @@ gimp_ink_motion (GimpPaintCore    *paint_core,
   GeglColor      *color;
   GimpBlob       *last_blob;
   GimpCoords     *coords;
-  gint            nstrokes;
+  gint            n_strokes;
   gint            i;
 
-  nstrokes = gimp_symmetry_get_size (sym);
+  n_strokes = gimp_symmetry_get_size (sym);
 
   if (ink->last_blobs &&
-      g_list_length (ink->last_blobs) != nstrokes)
+      g_list_length (ink->last_blobs) != n_strokes)
     {
       g_list_free_full (ink->last_blobs, g_free);
       ink->last_blobs = NULL;
@@ -324,7 +324,7 @@ gimp_ink_motion (GimpPaintCore    *paint_core,
           ink->start_blobs = NULL;
         }
 
-      for (i = 0; i < nstrokes; i++)
+      for (i = 0; i < n_strokes; i++)
         {
           coords = gimp_symmetry_get_coords (sym, i);
 
@@ -348,7 +348,7 @@ gimp_ink_motion (GimpPaintCore    *paint_core,
     }
   else
     {
-      for (i = 0; i < nstrokes; i++)
+      for (i = 0; i < n_strokes; i++)
         {
           GimpBlob *blob;
           GimpBlob *blob_union = NULL;
@@ -375,7 +375,7 @@ gimp_ink_motion (GimpPaintCore    *paint_core,
     }
 
   /* Get the buffer */
-  for (i = 0; i < nstrokes; i++)
+  for (i = 0; i < n_strokes; i++)
     {
       GimpBlob *blob_to_render = g_list_nth_data (blobs_to_render, i);
 
diff --git a/app/paint/gimppaintbrush.c b/app/paint/gimppaintbrush.c
index 197627d..2236b39 100644
--- a/app/paint/gimppaintbrush.c
+++ b/app/paint/gimppaintbrush.c
@@ -125,11 +125,11 @@ _gimp_paintbrush_motion (GimpPaintCore    *paint_core,
   const GimpCoords         *coords;
   GeglNode                 *op;
   gint                      i;
-  gint                      nstrokes;
+  gint                      n_strokes;
 
   image = gimp_item_get_image (GIMP_ITEM (drawable));
 
-  nstrokes = gimp_symmetry_get_size (sym);
+  n_strokes = gimp_symmetry_get_size (sym);
 
   fade_point = gimp_paint_options_get_fade (paint_options, image,
                                             paint_core->pixel_dist);
@@ -152,7 +152,8 @@ _gimp_paintbrush_motion (GimpPaintCore    *paint_core,
                                                paint_options,
                                                fade_point);
 
-  for (i = 0; i < nstrokes; i++)
+
+  for (i = 0; i < n_strokes; i++)
     {
       gint paint_width, paint_height;
 
diff --git a/app/paint/gimpperspectiveclone.c b/app/paint/gimpperspectiveclone.c
index 1148225..ac94005 100644
--- a/app/paint/gimpperspectiveclone.c
+++ b/app/paint/gimpperspectiveclone.c
@@ -289,11 +289,11 @@ gimp_perspective_clone_paint (GimpPaintCore    *paint_core,
 
           gint        dest_x;
           gint        dest_y;
-          gint        nstrokes;
+          gint        n_strokes;
           gint        i;
 
-          nstrokes = gimp_symmetry_get_size (sym);
-          for (i = 0; i < nstrokes; i++)
+          n_strokes = gimp_symmetry_get_size (sym);
+          for (i = 0; i < n_strokes; i++)
             {
               coords = gimp_symmetry_get_coords (sym, i);
 
diff --git a/app/paint/gimpsmudge.c b/app/paint/gimpsmudge.c
index 2df2639..6180df3 100644
--- a/app/paint/gimpsmudge.c
+++ b/app/paint/gimpsmudge.c
@@ -181,12 +181,12 @@ gimp_smudge_start (GimpPaintCore    *paint_core,
   gint        paint_buffer_x;
   gint        paint_buffer_y;
   gint        accum_size;
-  gint        nstrokes;
+  gint        n_strokes;
   gint        i;
   gint        x, y;
 
-  nstrokes = gimp_symmetry_get_size (sym);
-  for (i = 0; i < nstrokes; i++)
+  n_strokes = gimp_symmetry_get_size (sym);
+  for (i = 0; i < n_strokes; i++)
     {
       GeglBuffer *accum_buffer;
 
@@ -281,14 +281,14 @@ gimp_smudge_motion (GimpPaintCore    *paint_core,
   GimpCoords         *coords;
   GeglNode           *op;
   gint                paint_width, paint_height;
-  gint                nstrokes;
+  gint                n_strokes;
   gint                i;
 
   fade_point = gimp_paint_options_get_fade (paint_options, image,
                                             paint_core->pixel_dist);
 
-  nstrokes = gimp_symmetry_get_size (sym);
-  for (i = 0; i < nstrokes; i++)
+  n_strokes = gimp_symmetry_get_size (sym);
+  for (i = 0; i < n_strokes; i++)
     {
       coords = gimp_symmetry_get_coords (sym, i);
 
diff --git a/app/paint/gimpsourcecore.c b/app/paint/gimpsourcecore.c
index 0939bca..3a2060d 100644
--- a/app/paint/gimpsourcecore.c
+++ b/app/paint/gimpsourcecore.c
@@ -379,14 +379,14 @@ gimp_source_core_motion (GimpSourceCore   *source_core,
   GeglNode          *op;
   GimpCoords        *origin;
   GimpCoords        *coords;
-  gint               nstrokes;
+  gint               n_strokes;
   gint               i;
 
   fade_point = gimp_paint_options_get_fade (paint_options, image,
                                             paint_core->pixel_dist);
 
   origin   = gimp_symmetry_get_origin (sym);
-  nstrokes = gimp_symmetry_get_size (sym);
+  n_strokes = gimp_symmetry_get_size (sym);
 
   /* Some settings are based on the original stroke. */
   opacity = gimp_dynamics_get_linear_value (dynamics,
@@ -421,7 +421,7 @@ gimp_source_core_motion (GimpSourceCore   *source_core,
       gimp_pickable_flush (src_pickable);
     }
 
-  for (i = 0; i < nstrokes; i++)
+  for (i = 0; i < n_strokes; i++)
     {
       coords = gimp_symmetry_get_coords (sym, i);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/core/gimpsymmetry.c b/app/core/gimpsymmetry.c
index ec3feab..9685dc6 100644
--- a/app/core/gimpsymmetry.c
+++ b/app/core/gimpsymmetry.c
@@ -70,7 +70,7 @@ static GeglNode *
                                            gint          paint_height);
 static GParamSpec **
           gimp_symmetry_real_get_settings (GimpSymmetry *sym,
-                                           guint        *nproperties);
+                                           guint        *n_properties);
 
 G_DEFINE_TYPE (GimpSymmetry, gimp_symmetry, GIMP_TYPE_OBJECT)
 
@@ -215,9 +215,9 @@ gimp_symmetry_real_get_op (GimpSymmetry *sym,
 
 static GParamSpec **
 gimp_symmetry_real_get_settings (GimpSymmetry *sym,
-                                 guint        *nproperties)
+                                 guint        *n_properties)
 {
-  *nproperties = 0;
+  *n_properties = 0;
 
   return NULL;
 }
@@ -335,7 +335,7 @@ gimp_symmetry_get_operation (GimpSymmetry *sym,
 /**
  * gimp_symmetry_get_settings:
  * @sym:     the #GimpSymmetry
  * @nproperties: the number of properties in the returned array
  *
  * Returns an array of the symmetry properties which are supposed to
  * be settable by the user.
@@ -343,18 +343,18 @@ gimp_symmetry_get_operation (GimpSymmetry *sym,
  **/
 GParamSpec **
 gimp_symmetry_get_settings (GimpSymmetry *sym,
-                            guint        *nproperties)
+                            guint        *n_properties)
 {
   g_return_val_if_fail (GIMP_IS_SYMMETRY (sym), NULL);
 
   return GIMP_SYMMETRY_GET_CLASS (sym)->get_settings (sym,
-                                                      nproperties);
+                                                      n_properties);
 }
 
 /**
  * gimp_symmetry_get_xcf_settings:
  * @sym:         the #GimpSymmetry
  * @nproperties: the number of properties in the returned array
  *
  * Returns an array of the symmetry properties which are to be serialized
  * when saving to XCF.
@@ -365,10 +365,10 @@ gimp_symmetry_get_settings (GimpSymmetry *sym,
  **/
 GParamSpec **
 gimp_symmetry_get_xcf_settings (GimpSymmetry *sym,
-                                guint        *nproperties)
+                                guint        *n_properties)
 {
   g_return_val_if_fail (GIMP_IS_SYMMETRY (sym), NULL);
 
   return GIMP_SYMMETRY_GET_CLASS (sym)->get_xcf_settings (sym,
-                                                          nproperties);
+                                                          n_properties);
 }
@@ -335,7 +335,7 @@ gimp_symmetry_get_operation (GimpSymmetry *sym,
  * gimp_symmetry_get_settings:
  * @sym:     the #GimpSymmetry
- * @nproperties: the number of properties in the returned array
+ * @n_properties: the number of properties in the returned array
  *
  * Returns an array of the symmetry properties which are supposed to
@@ -343,18 +343,18 @@ gimp_symmetry_get_operation (GimpSymmetry *sym,
  * gimp_symmetry_get_xcf_settings:
  * @sym:         the #GimpSymmetry
- * @nproperties: the number of properties in the returned array
+ * @n_properties: the number of properties in the returned array
  *
  * Returns an array of the symmetry properties which are to be serialized